<?php

function getPageURL($taxonomy, $pageURL, $searchQuery, $termID) {
    $term = get_term($termID);

    if (!$term || !$term->name):
        return $pageURL;
    endif;

    if ($searchQuery['s'] && $taxonomy == 'city'):
        return '/?city=' . $term->name . '&s=' . $searchQuery['s'];
    elseif ($searchQuery['city'] && ($taxonomy == 'type' || $taxonomy == 'field')):
        return '/?city=' . $searchQuery['city'] . '&s=' . $term->name;
    endif;

    return $pageURL;
}

function getSiteTree($taxonomy, $section, $searchQuery) {
    $terms = get_terms( array(
        'taxonomy' => $taxonomy,
        'hide_empty' => false,
    ));

    if ( !empty( $terms ) && ! is_wp_error( $terms ) ):
        $res = array();

        if ($searchQuery['city']):
            $city = get_term_by( 'name', preg_replace('/[\+]/', ' ', $searchQuery['city']), 'city' );
        endif;

        if ($searchQuery['s']):
            $field = get_term_by( 'name', preg_replace('/[\+]/', ' ', $searchQuery['s']), 'field' );
            $type = get_term_by( 'name', preg_replace('/[\+]/', ' ', $searchQuery['s']), 'type' );
        endif;

        foreach ( $terms as $term ):
            $termID = $term->term_id;
            $active = false;

            $where = 'valid.meta_value > "' . date('Y-m-d', strtotime('-1 days')) . '" AND ' . $taxonomy . '.term_id = ' . $termID;
            $counter = $where;

            if ($taxonomy == 'city'):
                if ( $field ) :
                    $counter = $counter . ' AND field.term_id = ' . $field->term_id;
                elseif ( $type ) :
                    $counter = $counter . ' AND type.term_id = ' . $type->term_id;
                else:
                    $counter = $counter . ' AND (t.post_title LIKE "%' . $searchQuery['s'] . '%" OR  t.post_content LIKE "%' . $searchQuery['s'] . '%")';
                endif;

                if ( $city && $city->term_id == $termID ) :
                    $active = true;
                endif;

            elseif ($taxonomy == 'type' || $taxonomy == 'field'):
                if ( $city ) :
                    $counter = $counter . ' AND city.term_id = ' . $city->term_id;
                endif;

                if ( $field && $field->term_id == $termID || $type && $type->term_id == $termID) :
                    $active = true;
                endif;
            endif;

            $params = array(
                'where' => $where,
                'limit'   => -1
            );

            $jobsIn = pods( 'job', $params );

            $custom = array(
                'where' => $counter,
                'limit'   => -1
            );

            $jobsCounter = pods( 'job', $custom );

            if ( 0 < $jobsIn->total() ):
                $page = get_term_meta( $termID, 'page-id', true);
                $order = intval(get_term_meta( $termID, 'order', true));

                if ( $page && $page['post_status'] === 'publish') :

                    array_push($res, array(
                        'name' => $page['post_title'],
                        'href' => getPageURL($taxonomy, get_page_link( $page['ID'] ), $searchQuery, $termID),
                        'order' => $order,
                        'total' => $jobsCounter->total(),
                        'active' => $active
                    ));

                endif;
            endif;
        endforeach;

        if (count($res) == 0) {
            return '';
        }

        usort($res, function($a, $b) {
            $o = $b['order'] - $a['order'];
            if ($o):
                return $o;
            endif;
            $t = $b['total'] - $a['total'];
            if ($t):
                return $t;
            endif;

            return $a['name'] > $b['name'];
        });


        $classCSS = 'c-jobs-section';

        $isClosed = count($res) > 6;

        if ($isClosed):

            $classCSS .= ' c-jobs-section--is-closed';

        endif;

        echo '<div class="' . $classCSS . '">';
            echo '<h3 class="c-jobs-section--heading">' . $section . '</h3>';

            echo '<div class="c-jobs-section--content">';
                echo '<ul  class="c-jobs-section--list">';

                foreach ( $res as $r ):
?>
                    <li class="c-jobs-section--item <?php if ($r['active']): echo 'c-jobs-section--item-active'; endif; ?>"><a href="<?php echo $r['href']; ?>" title="<?php echo $r['name']; ?>" class="c-jobs-section--anchor"><?php echo $r['name'] . ' (' . $r['total'] . ')'; ?></a></li>
<?php
                endforeach;

             echo '</ul>';

            echo '</div>';

        if ($isClosed):
            echo '<a href="#" class="js-expand-jobs-section c-jobs-section--expand">' . __('More ...', 'biuro') . ' </a>';
        endif;

        echo '</div>';

     endif;
}


    global $query_string;

    wp_parse_str( $query_string, $searchQuery );

    $pageTerms = getPageTerm(get_post_custom_keys());

    if ($pageTerms):
        if ($pageTerms->taxonomy === 'type' || $pageTerms->taxonomy === 'field'):
            $searchQuery['s'] = $pageTerms->name;
        elseif ($pageTerms->taxonomy === 'city'):
            $searchQuery['city'] = $pageTerms->name;
        endif;
    endif;


    getSiteTree( 'city', __('City', 'biuro'), $searchQuery );
?>

<?php
    getSiteTree( 'field', __('Job area', 'biuro'), $searchQuery );
?>

<?php
    getSiteTree( 'type', __('Job type', 'biuro'), $searchQuery );
?>

<?php
    global $positionsPage;

    if ($positionsPage):
?>
    <p class="c-search--reset">
        <a href="<?php echo $positionsPage; ?>" class="o-btn c-btn--main"><?php _e('Reset filters', 'biuro'); ?></a>
    </p>
<?php
    endif;
?>

<?php

    $VSD = get_term_by( 'slug', 'type-8-lt', 'type' );

if ($VSD && $VSD->name == $searchQuery['s']): ?>

    <div class="c-vdb--section c-vdb--section-aside">
        <img src="/wp-content/themes/biuro/i/vdb/not-found.png" width="85px" height="85px" alt="VDB not found" class="c-vdb--section-img" />
        <h3 class="c-vdb--section-heading"><?php _e("Didn't find a job offer you like?", 'biuro'); ?></h3>
        <p class="c-vdb--section-content">
            <?php _e('Fill out the form and we will contact you', 'biuro'); ?>
        </p>
    <?php
        $contactsPage = new WP_Query( array(
            'numberposts'   => 1,
            'post_type'     => 'page',
            'meta_key'      => 'page',
            'meta_value'    => 'employees-contacts'
        ) );

        if ( $contactsPage->have_posts() ) :
            while( $contactsPage->have_posts() ) :
                $contactsPage->the_post();
        ?>
                <a href="<?php echo get_the_permalink(); ?>?#action" class="o-btn c-btn--vdb"><?php _e('Get a job offer', 'biuro'); ?></a>
        <?php
            endwhile;
        endif;
        wp_reset_query();
     ?>
    </div>

<?php endif; ?>
